@@ -11,13 +11,12 @@ use warnings FATAL => 'all';
 
 package [% class_v %]::Root;
 use base 'HTML::Tested::ClassDBI';
-use HTML::Tested qw(HTV);
 use [% root_class_v %]::DB::[% table_class_v %];
-__PACKAGE__->ht_add_widget(HTV."::Form", form => default_value => 'u');
+__PACKAGE__->ht_add_widget(::HTV."::Form", form => default_value => 'u');
 [% FOREACH fields_v %]
-__PACKAGE__->ht_add_widget(HTV."::Marked"
+__PACKAGE__->ht_add_widget(::HTV."::Marked"
 	, [% field %] => cdbi_bind => '');[% END %]
-__PACKAGE__->ht_add_widget(HTV."::Link", 'edit_link'
+__PACKAGE__->ht_add_widget(::HTV."::Link", 'edit_link'
 		, href_format => '../form/r?ht_id=%s'
 		, caption => 'Edit', cdbi_bind => [ 'Primary' ]);
 __PACKAGE__->bind_to_class_dbi('[% root_class_v %]::DB::[% table_class_v %]');
@@ -25,7 +24,6 @@ __PACKAGE__->bind_to_class_dbi('[% root_class_v %]::DB::[% table_class_v %]');
 package [% class_v %];
 use base qw(Apache::SWIT::HTPage);
 
-sub ht_root_class { return __PACKAGE__ . '::Root'; }
 
 sub ht_swit_render {
 	my ($class, $r, $root) = @_;
