@@ -1,6 +1,7 @@
 use T::DBPage;
 use T::SessPage;
 use T::HTPage;
+use T::HTError;
 use T::Upload;
 use T::SWIT;
 use T::Res;
@@ -10,5 +11,7 @@ use Apache::SWIT::LargeObjectHandler;
 T::SWIT->swit_startup;
 T::SessPage->swit_startup;
 T::HTPage->swit_startup;
+T::HTError->swit_startup;
+T::DBPage->swit_startup;
 
 1;
